
-- the init_weights function is a good place for changing settings like
-- village types
old_init_weights = mg_villages.init_weights
mg_villages.init_weights = function()
	-- reduce size of all registered village types in order to get
	-- smaller villages
	for k,v in pairs(mg_villages.village_type_data) do
		if(v and v.max and v.max > 20) then
			mg_villages.village_type_data[k].max = 20
		end
		if(v and v.max and v.min > 10) then
			mg_villages.village_type_data[k].min = 10
		end
	end

	-- forbid generation of villages of type "taoki"
	mg_villages.village_type_data['taoki'].supported = nil

	for i,v in ipairs(handle_schematics.random_chest_content) do
	-- v is structured like this:
	-- v[1]  stack name
	-- v[2]  probability (0..100); stack will be put in the chest if v[2] > random(1,200)
	-- v[3]  maximum stack size that can be found in each slot of a chest
	-- v[4]  up to this many inventory slots of the chest may recive such a stack
		-- do not let the probability for any stack get too high
		if(v[2] > 50) then
			handle_schematics.random_chest_content[i][2] = 50
		end
		-- do not let each stack get over 20 items large
		if(v[3] > 20) then
			handle_schematics.random_chest_content[i][3] = 20
		end
		if(   v[1]=="default:diamondblock"
		   or v[1]=="default:diamond"
		   or v[1]=="default:mese") then
		   	-- relatively low probability
			handle_schematics.random_chest_content[i][2] = 5
			-- no more than one of these items per stack
			handle_schematics.random_chest_content[i][3] = 1
			-- and no more than two stacks inside each chest
			handle_schematics.random_chest_content[i][4] = 2
		end
	end
	-- add a small chance to find a diamond in a normal chest
	table.insert(handle_schematics.random_chest_content,
		    {"default:diamond", 10, 1, 1, default_chest=1})

	-- call the old function so that everything gets set up properly
	old_init_weights()
end


-- not really needed as we already depend on mg_villages in depends.txt
if(mg_villages) then
	-- do not place plot marker stones and do not protect villages
	-- against griefing
	mg_villages.ENABLE_PROTECTION = false

	-- do not spawn the player inside a village
	mg_villages.spawnplayer = function(player)
	end

	-- new: set this to a value higher than 200 in order to get less chest
	-- content in general (chest will recive a stack at the given slot if
	-- handle_schematics.random_chest_content[i][2] > random(1,
	--    handle_schematics.random_chest_probability_factor)
	handle_schematics.random_chest_probability_factor = 1000
end
